@@ -1,5 +1,3 @@
-/* $Xorg: Command.c,v 1.5 2001/02/09 02:03:43 xorgcvs Exp $ */
-
 /***********************************************************
 
 Copyright 1987, 1988, 1994, 1998  The Open Group
@@ -29,13 +27,13 @@ Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
-Permission to use, copy, modify, and distribute this software and its 
-documentation for any purpose and without fee is hereby granted, 
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted,
 provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in 
+both that copyright notice and this permission notice appear in
 supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
-software without specific, written prior permission.  
+software without specific, written prior permission.
 
 DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
@@ -46,7 +44,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $XFree86: xc/lib/Xaw/Command.c,v 1.15tsi Exp $ */
 
 /*
  * Command.c - Command button widget
@@ -113,7 +110,7 @@ static char defaultTranslations[] =
 ;
 
 #define offset(field) XtOffsetOf(CommandRec, field)
-static XtResource resources[] = { 
+static XtResource resources[] = {
   {
     XtNcallback,
     XtCCallback,
@@ -219,21 +216,21 @@ WidgetClass commandWidgetClass = (WidgetClass)&commandClassRec;
 /*
  * Implementation
  */
-static GC 
+static GC
 Get_GC(CommandWidget cbw, Pixel fg, Pixel bg)
 {
     XGCValues	values;
-  
+
     values.foreground	= fg;
     values.background	= bg;
     values.font		= cbw->label.font->fid;
     values.cap_style	= CapProjecting;
-  
+
     if (cbw->command.highlight_thickness > 1)
 	values.line_width = cbw->command.highlight_thickness;
-    else 
+    else
 	values.line_width = 0;
-  
+
     if (cbw->simple.international == True)
 	return (XtAllocateGC((Widget)cbw, 0,
 			     GCForeground | GCBackground | GCLineWidth |
@@ -245,15 +242,15 @@ Get_GC(CommandWidget cbw, Pixel fg, Pixel bg)
 }
 
 /*ARGSUSED*/
-static void 
-XawCommandInitialize(Widget request, Widget cnew,
-		     ArgList args, Cardinal *num_args)
+static void
+XawCommandInitialize(Widget request _X_UNUSED, Widget cnew,
+		     ArgList args _X_UNUSED, Cardinal *num_args _X_UNUSED)
 {
     CommandWidget cbw = (CommandWidget)cnew;
     int shape_event_base, shape_error_base;
 
     if (!cbw->label.font) XtError("Aborting: no font found\n");
-    
+
     if (cbw->command.shape_style != XawShapeRectangle &&
 	!XShapeQueryExtension(XtDisplay(cnew), &shape_event_base,
 			      &shape_error_base))
@@ -266,9 +263,9 @@ XawCommandInitialize(Widget request, Widget cnew,
 	    cbw->command.highlight_thickness = DEFAULT_HIGHLIGHT_THICKNESS;
     }
 
-    cbw->command.normal_GC = Get_GC(cbw, cbw->label.foreground, 
+    cbw->command.normal_GC = Get_GC(cbw, cbw->label.foreground,
 				    cbw->core.background_pixel);
-    cbw->command.inverse_GC = Get_GC(cbw, cbw->core.background_pixel, 
+    cbw->command.inverse_GC = Get_GC(cbw, cbw->core.background_pixel,
 				     cbw->label.foreground);
     XtReleaseGC(cnew, cbw->label.normal_GC);
     cbw->label.normal_GC = cbw->command.normal_GC;
@@ -277,7 +274,7 @@ XawCommandInitialize(Widget request, Widget cnew,
     cbw->command.highlighted = HighlightNone;
 }
 
-static Region 
+static Region
 HighlightRegion(CommandWidget cbw)
 {
     static Region outerRegion = NULL, innerRegion, emptyRegion;
@@ -298,9 +295,9 @@ HighlightRegion(CommandWidget cbw)
     rect.width = XtWidth(cbw);
     rect.height = XtHeight(cbw);
     XUnionRectWithRegion(&rect, emptyRegion, outerRegion);
-    rect.x = rect.y = cbw->command.highlight_thickness;
-    rect.width -= cbw->command.highlight_thickness * 2;
-    rect.height -= cbw->command.highlight_thickness * 2;
+    rect.x = rect.y = (short)cbw->command.highlight_thickness;
+    rect.width = (rect.width - cbw->command.highlight_thickness * 2);
+    rect.height = (rect.height - cbw->command.highlight_thickness * 2);
     XUnionRectWithRegion(&rect, emptyRegion, innerRegion);
     XSubtractRegion(outerRegion, innerRegion, outerRegion);
 
@@ -326,8 +323,8 @@ XawCommandToggle(Widget w)
 }
 
 /*ARGSUSED*/
-static void 
-Set(Widget w, XEvent *event, String *params, Cardinal *num_params)
+static void
+Set(Widget w, XEvent *event _X_UNUSED, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     CommandWidget cbw = (CommandWidget)w;
 
@@ -340,7 +337,7 @@ Set(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 /*ARGSUSED*/
 static void
-Unset(Widget w, XEvent *event, String *params, Cardinal *num_params)
+Unset(Widget w, XEvent *event _X_UNUSED, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     CommandWidget cbw = (CommandWidget)w;
 
@@ -352,7 +349,7 @@ Unset(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 
 /*ARGSUSED*/
-static void 
+static void
 Reset(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     CommandWidget cbw = (CommandWidget)w;
@@ -366,7 +363,7 @@ Reset(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 
 /*ARGSUSED*/
-static void 
+static void
 Highlight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     CommandWidget cbw = (CommandWidget)w;
@@ -392,8 +389,8 @@ Highlight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 
 /*ARGSUSED*/
-static void 
-Unhighlight(Widget w, XEvent *event, String *params, Cardinal *num_params)
+static void
+Unhighlight(Widget w, XEvent *event, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     CommandWidget cbw = (CommandWidget)w;
 
@@ -403,10 +400,10 @@ Unhighlight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 
 /*ARGSUSED*/
-static void 
-Notify(Widget w, XEvent *event, String *params, Cardinal *num_params)
+static void
+Notify(Widget w, XEvent *event _X_UNUSED, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
-    CommandWidget cbw = (CommandWidget)w; 
+    CommandWidget cbw = (CommandWidget)w;
 
     /* check to be sure state is still Set so that user can cancel
        the action (e.g. by moving outside the window, in the default
@@ -430,13 +427,13 @@ XawCommandRedisplay(Widget w, XEvent *event, Region region)
  *	region - region to paint (passed to the superclass)
  *                 change - did it change either set or highlight state?
  */
-static void 
+static void
 PaintCommandWidget(Widget w, XEvent *event, Region region, Bool change)
 {
     CommandWidget cbw = (CommandWidget)w;
     Bool very_thick;
     GC rev_gc;
-   
+
     very_thick = cbw->command.highlight_thickness
 		 > Min(XtWidth(cbw), XtHeight(cbw)) / 2;
 
@@ -472,13 +469,13 @@ PaintCommandWidget(Widget w, XEvent *event, Region region, Bool change)
 		XClearArea(XtDisplay(w), XtWindow(w),
 			   0, cbw->command.highlight_thickness,
 			   cbw->command.highlight_thickness,
-			   XtHeight(cbw) - (cbw->command.highlight_thickness<<1),
+			   (unsigned)(XtHeight(cbw) - (cbw->command.highlight_thickness<<1)),
 			   False);
 		XClearArea(XtDisplay(w), XtWindow(w),
 			   XtWidth(cbw) - cbw->command.highlight_thickness,
 			   cbw->command.highlight_thickness,
 			   cbw->command.highlight_thickness,
-			   XtHeight(cbw) - (cbw->command.highlight_thickness<<1),
+			   (unsigned)(XtHeight(cbw) - (cbw->command.highlight_thickness<<1)),
 			   False);
 		XClearArea(XtDisplay(w), XtWindow(w),
 			   0, XtHeight(cbw) - cbw->command.highlight_thickness,
@@ -488,9 +485,9 @@ PaintCommandWidget(Widget w, XEvent *event, Region region, Bool change)
 	    else {
 		int offset = cbw->command.highlight_thickness / 2;
 
-		XDrawRectangle(XtDisplay(w),XtWindow(w), rev_gc, offset, offset, 
-			       XtWidth(cbw) - cbw->command.highlight_thickness,
-			      XtHeight(cbw) - cbw->command.highlight_thickness);
+		XDrawRectangle(XtDisplay(w),XtWindow(w), rev_gc, offset, offset,
+			       (unsigned)(XtWidth(cbw) - cbw->command.highlight_thickness),
+			       (unsigned)(XtHeight(cbw) - cbw->command.highlight_thickness));
 	   }
 	}
     }
@@ -498,7 +495,7 @@ PaintCommandWidget(Widget w, XEvent *event, Region region, Bool change)
     (*SuperClass->core_class.expose)(w, event, region);
 }
 
-static void 
+static void
 XawCommandDestroy(Widget w)
 {
     CommandWidget cbw = (CommandWidget)w;
@@ -508,8 +505,8 @@ XawCommandDestroy(Widget w)
 }
 
 /*ARGSUSED*/
-static Boolean 
-XawCommandSetValues(Widget current, Widget request, Widget cnew,
+static Boolean
+XawCommandSetValues(Widget current, Widget request _X_UNUSED, Widget cnew,
 		    ArgList args, Cardinal *num_args)
 {
     CommandWidget oldcbw = (CommandWidget)current;
@@ -544,9 +541,9 @@ XawCommandSetValues(Widget current, Widget request, Widget cnew,
 	|| oldcbw->label.font != cbw->label.font) {
 	XtReleaseGC(cnew, cbw->command.inverse_GC);
 
-	cbw->command.normal_GC = Get_GC(cbw, cbw->label.foreground, 
+	cbw->command.normal_GC = Get_GC(cbw, cbw->label.foreground,
 					cbw->core.background_pixel);
-	cbw->command.inverse_GC = Get_GC(cbw, cbw->core.background_pixel, 
+	cbw->command.inverse_GC = Get_GC(cbw, cbw->core.background_pixel,
 					 cbw->label.foreground);
 	XtReleaseGC(cnew, cbw->label.normal_GC);
 	cbw->label.normal_GC = cbw->command.normal_GC;
@@ -596,7 +593,7 @@ ShapeButton(CommandWidget cbw, Bool checkRectangular)
     if (cbw->command.shape_style == XawShapeRoundedRectangle) {
 	corner_size = XtWidth(cbw) < XtHeight(cbw) ?
 			XtWidth(cbw) : XtHeight(cbw);
-	corner_size = (corner_size * cbw->command.corner_round) / 100;
+	corner_size = (Dimension)((corner_size * cbw->command.corner_round) / 100);
     }
 
     if (checkRectangular || cbw->command.shape_style != XawShapeRectangle) {
@@ -622,7 +619,7 @@ XawCommandRealize(Widget w, Mask *valueMask, XSetWindowAttributes *attributes)
 static void
 XawCommandResize(Widget w)
 {
-    if (XtIsRealized(w)) 
+    if (XtIsRealized(w))
 	ShapeButton((CommandWidget)w, False);
 
     (*commandWidgetClass->core_class.superclass->core_class.resize)(w);
