@@ -78,14 +78,6 @@ in this Software without prior written authorization from The Open Group.
 #define MAGIC_VALUE	((XawTextPosition)-1)
 #define streq(a, b)	(strcmp((a), (b)) == 0)
 
-#ifdef X_NOT_POSIX
-#define Off_t long
-#define Size_t unsigned int
-#else
-#define Off_t off_t
-#define Size_t size_t
-#endif
-
 
 /*
  * Class Methods
@@ -120,7 +112,7 @@ static FILE *InitStringOrFile(MultiSrcObject, Bool);
 static void LoadPieces(MultiSrcObject, FILE*, char*);
 static void RemovePiece(MultiSrcObject, MultiPiece*);
 static void RemoveOldStringOrFile(MultiSrcObject, Bool);
-static String StorePiecesInString(MultiSrcObject);
+static char * StorePiecesInString(MultiSrcObject);
 static Bool WriteToFile(String, String);
 static void GetDefaultPieceSize(Widget, int, XrmValue*);
 
@@ -170,7 +162,7 @@ static XtResource resources[] = {
     XtNcallback,
     XtCCallback,
     XtRCallback,
-    sizeof(XtPointer), 
+    sizeof(XtPointer),
     offset(callback),
     XtRCallback,
     (XtPointer)NULL
@@ -242,6 +234,9 @@ MultiSrcClassRec multiSrcClassRec = {
     Search,				/* Search */
     XtInheritSetSelection,		/* SetSelection */
     XtInheritConvertSelection,		/* ConvertSelection */
+#ifndef OLDXAW
+    NULL
+#endif
   },
   /* multi_src */
   {
@@ -282,8 +277,8 @@ XawMultiSrcClassInitialize(void)
  */
 /*ARGSUSED*/
 static void
-XawMultiSrcInitialize(Widget request, Widget cnew,
-		      ArgList args, Cardinal *num_args)
+XawMultiSrcInitialize(Widget request _X_UNUSED, Widget cnew,
+		      ArgList args _X_UNUSED, Cardinal *num_args _X_UNUSED)
 {
     MultiSrcObject src = (MultiSrcObject)cnew;
     FILE *file;
@@ -306,7 +301,7 @@ XawMultiSrcInitialize(Widget request, Widget cnew,
 
     if (file != NULL)
 	fclose(file);
-    src->text_src.text_format = XawFmtWide;
+    src->text_src.text_format = (XrmQuark)XawFmtWide;
 }
 
 /*
@@ -331,12 +326,12 @@ ReadText(Widget w, XawTextPosition pos, XawTextBlock *text, int length)
     MultiSrcObject src = (MultiSrcObject)w;
     XawTextPosition count, start;
     MultiPiece *piece = FindPiece(src, pos, &start);
-    
+
     text->format = XawFmtWide;
-    text->firstPos = pos;
+    text->firstPos = (int)pos;
     text->ptr = (char *)(piece->text + (pos - start));
     count = piece->used - (pos - start);
-    text->length = Max(0, (length > count) ? count : length);
+    text->length = (Max(0, (length > count) ? count : length));
 
     return (pos + text->length);
 }
@@ -358,7 +353,7 @@ ReadText(Widget w, XawTextPosition pos, XawTextBlock *text, int length)
  *	XawEditDone on success, XawEditError otherwise
  */
 /*ARGSUSED*/
-static int 
+static int
 ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
 	    XawTextBlock *u_text_p)
 {
@@ -370,9 +365,9 @@ ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
     Bool local_artificial_block = False;
     XawTextBlock text;
 
-    /* STEP 1: The user handed me a text block called `u_text' that may be 
-     * in either FMTWIDE or FMT8BIT (ie MB.)  Later code needs the block 
-     * `text' to hold FMTWIDE.	So, this copies `u_text' to `text', and if 
+    /* STEP 1: The user handed me a text block called `u_text' that may be
+     * in either FMTWIDE or FMT8BIT (ie MB.)  Later code needs the block
+     * `text' to hold FMTWIDE.	So, this copies `u_text' to `text', and if
      * `u_text' was MB, I knock it up to WIDE
      */
     if (u_text_p->length == 0)	/* if so, the block contents never ref'd */
@@ -406,7 +401,7 @@ ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
     }
 
     /* STEP 2: some initialization... */
-    if (src->text_src.edit_mode == XawtextRead) 
+    if (src->text_src.edit_mode == XawtextRead)
 	return (XawEditError);
 
     start_piece = FindPiece(src, startPos, &start_first);
@@ -428,7 +423,7 @@ ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
 	end_piece->used -= endPos - end_first;
 	if (end_piece->used != 0)
 	    memmove(end_piece->text, end_piece->text + endPos - end_first,
-		    end_piece->used * sizeof(wchar_t));
+		    (size_t)end_piece->used * sizeof(wchar_t));
     }
     else {		    /* We are fully in one piece */
 	if ((start_piece->used -= endPos - startPos) == 0) {
@@ -438,7 +433,7 @@ ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
 	else {
 	    memmove(start_piece->text + (startPos - start_first),
 		    start_piece->text + (endPos - start_first),
-		    (start_piece->used - (startPos - start_first)) *
+		    (size_t)(start_piece->used - (startPos - start_first)) *
 		    sizeof(wchar_t));
 	    if (src->multi_src.use_string_in_place &&
 		((src->multi_src.length - (endPos - startPos))
@@ -455,11 +450,11 @@ ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
         start_piece = FindPiece(src, startPos, &start_first);
         length = text.length;
         firstPos = text.firstPos;
-    
+
 	while (length > 0) {
 	    wchar_t *ptr;
 	    int fill;
-      
+
 	    if (src->multi_src.use_string_in_place) {
 		if (start_piece->used == src->multi_src.piece_size - 1)  {
 
@@ -481,13 +476,13 @@ ReplaceText(Widget w, XawTextPosition startPos, XawTextPosition endPos,
 	    }
 
 	    fill = Min((int)(src->multi_src.piece_size - start_piece->used), length);
-      
+
 	    ptr = start_piece->text + (startPos - start_first);
-	    memmove(ptr + fill, ptr, (start_piece->used -
+	    memmove(ptr + fill, ptr, (size_t)(start_piece->used -
 		    (startPos - start_first)) * sizeof(wchar_t));
 	    wptr =(wchar_t *)text.ptr;
-	    (void)wcsncpy(ptr, wptr + firstPos, fill);
-      
+	    (void)wcsncpy(ptr, wptr + firstPos, (size_t)fill);
+
 	    startPos += fill;
 	    firstPos += fill;
 	    start_piece->used += fill;
@@ -606,7 +601,7 @@ Scan(Widget w, register XawTextPosition position, XawTextScanType type,
 		    position += inc;
 
 		    if (type == XawstAlphaNumeric) {
-			if (!iswalnum(c)) {
+			if (!iswalnum((wint_t)c)) {
 			    if (non_space)
 				break;
 			}
@@ -681,7 +676,7 @@ Scan(Widget w, register XawTextPosition position, XawTextScanType type,
  * Returns:
  *	The position of the item found
  */
-static XawTextPosition 
+static XawTextPosition
 Search(Widget w, register XawTextPosition position, XawTextScanDirection dir,
        XawTextBlock *text)
 {
@@ -728,8 +723,8 @@ Search(Widget w, register XawTextPosition position, XawTextScanDirection dir,
        effectively factored out of the following computations */
 
     /* STEP 3: SEARCH! */
-    buf = (wchar_t *)XtMalloc(sizeof(wchar_t) * wtarget_len);
-    (void)wcsncpy(buf, wtarget, wtarget_len);
+    buf = (wchar_t *)XtMalloc((Cardinal)(sizeof(wchar_t) * (size_t)wtarget_len));
+    (void)wcsncpy(buf, wtarget, (size_t)wtarget_len);
     piece = FindPiece(src, position, &first);
     ptr = (position - first) + piece->text;
 
@@ -752,9 +747,9 @@ Search(Widget w, register XawTextPosition position, XawTextScanDirection dir,
 
 	ptr += inc;
 	position += inc;
-    
+
 	while (ptr < piece->text) {
-	    cnt = piece->text - ptr;
+	    cnt = (int)(piece->text - ptr);
 
 	    piece = piece->prev;
 	    if (piece == NULL) {	/* Begining of text */
@@ -763,9 +758,9 @@ Search(Widget w, register XawTextPosition position, XawTextScanDirection dir,
 	    }
 	    ptr = piece->text + piece->used - cnt;
 	}
-   
+
 	while (ptr >= piece->text + piece->used) {
-	    cnt = ptr - (piece->text + piece->used);
+	    cnt = (int)(ptr - (piece->text + piece->used));
 
 	    piece = piece->next;
 	    if (piece == NULL) {	/* End of text */
@@ -801,7 +796,7 @@ Search(Widget w, register XawTextPosition position, XawTextScanDirection dir,
  *	True if redisplay is needed
  */
 static Boolean
-XawMultiSrcSetValues(Widget current, Widget request, Widget cnew,
+XawMultiSrcSetValues(Widget current, Widget request _X_UNUSED, Widget cnew,
 		     ArgList args, Cardinal *num_args)
 {
     MultiSrcObject src = (MultiSrcObject)cnew;
@@ -816,7 +811,7 @@ XawMultiSrcSetValues(Widget current, Widget request, Widget cnew,
 	XtAppWarning(app_con,
 		     "MultiSrc: The XtNuseStringInPlace resources "
 		     "may not be changed.");
-	src->multi_src.use_string_in_place = 
+	src->multi_src.use_string_in_place =
 	    old_src->multi_src.use_string_in_place;
     }
 
@@ -825,7 +820,7 @@ XawMultiSrcSetValues(Widget current, Widget request, Widget cnew,
 	    string_set = True;
 	    break;
 	}
-  
+
     if (string_set || old_src->multi_src.type != src->multi_src.type) {
 	RemoveOldStringOrFile(old_src, string_set);
 	src->multi_src.allocated_string = old_src->multi_src.allocated_string;
@@ -849,7 +844,7 @@ XawMultiSrcSetValues(Widget current, Widget request, Widget cnew,
 
     if ( !total_reset && old_src->multi_src.piece_size
 	 != src->multi_src.piece_size) {
-	String mb_string = StorePiecesInString(old_src);
+	char * mb_string = StorePiecesInString(old_src);
 
 	if (mb_string != 0) {
 	    FreeAllPieces(old_src);
@@ -890,14 +885,14 @@ XawMultiSrcGetValuesHook(Widget w, ArgList args, Cardinal *num_args)
     }
 }
 
-static void 
+static void
 XawMultiSrcDestroy(Widget w)
 {
     RemoveOldStringOrFile((MultiSrcObject) w, True);
 }
 
 /*
- * Public routines 
+ * Public routines
  */
 /*
  * Function:
@@ -952,14 +947,14 @@ _XawMultiSave(Widget w)
      * If using the string in place then there is no need to play games
      * to get the internal info into a readable string
      */
-    if (src->multi_src.use_string_in_place) 
+    if (src->multi_src.use_string_in_place)
 	return (True);
 
     if (src->multi_src.type == XawAsciiFile) {
 #ifdef OLDXAW
 	 if (!src->multi_src.changes)
 #else
-	if (!src->text_src.changed) 		/* No changes to save */
+	if (!src->text_src.changed)		/* No changes to save */
 #endif
 	    return (True);
 
@@ -1006,7 +1001,7 @@ _XawMultiSave(Widget w)
 	    XtFree((char *)src->multi_src.string);
 	else
 	    src->multi_src.allocated_string = True;
-    
+
         src->multi_src.string = mb_string;
     }
 #ifdef OLDXAW
@@ -1039,13 +1034,13 @@ Bool
 _XawMultiSaveAsFile(Widget w, _Xconst char* name)
 {
     MultiSrcObject src = (MultiSrcObject)w;
-    String mb_string;
+    char * mb_string;
     Bool ret;
 
     mb_string = StorePiecesInString(src);
 
     if (mb_string != 0) {
-	ret = WriteToFile(mb_string, (char *)name);
+	ret = WriteToFile(mb_string, (String)name);
 	XtFree(mb_string);
 
 	return (ret);
@@ -1092,15 +1087,18 @@ static Bool
 WriteToFile(String string, String name)
 {
     int fd;
-  
-    if (((fd = creat(name, 0666)) == -1)
-	|| (write(fd, string, strlen(string)) == -1))
+    Bool result = True;
+
+    if ((fd = creat(name, 0666)) == -1)
 	return (False);
 
+    if (write(fd, string, strlen(string)) == -1)
+        result = False;
+
     if (close(fd) == -1)
 	return (False);
 
-    return (True);
+    return (result);
 }
 
 
@@ -1119,21 +1117,21 @@ WriteToFile(String string, String name)
  *	(or)
  *	NULL:		conversion error
  */
-static String
+static char *
 StorePiecesInString(MultiSrcObject src)
 {
     wchar_t *wc_string;
     char *mb_string;
-    int char_count = src->multi_src.length;
+    int char_count = (int)src->multi_src.length;
     XawTextPosition first;
     MultiPiece *piece;
 
     /* I believe the char_count + 1 and the NULL termination are unneeded! FS */
-    wc_string = (wchar_t*)XtMalloc((char_count + 1) * sizeof(wchar_t));
+    wc_string = (wchar_t*)XtMalloc((Cardinal)((size_t)(char_count + 1) * sizeof(wchar_t)));
 
     for (first = 0, piece = src->multi_src.first_piece ; piece != NULL;
 	 first += piece->used, piece = piece->next)
-	(void)wcsncpy(wc_string + first, piece->text, piece->used);
+	(void)wcsncpy(wc_string + first, piece->text, (size_t)piece->used);
 
     wc_string[char_count] = 0;
 
@@ -1178,31 +1176,31 @@ InitStringOrFile(MultiSrcObject src, Bool newString)
 
 	else if (!src->multi_src.use_string_in_place) {
 	    int length;
-	    String temp = XtNewString((char *)src->multi_src.string);
+	    char * temp = XtNewString((char *)src->multi_src.string);
 
 	    if (src->multi_src.allocated_string)
 		XtFree((char *)src->multi_src.string);
 	    src->multi_src.allocated_string = True;
 	    src->multi_src.string = temp;
 
-	    length = strlen((char *)src->multi_src.string);
+	    length = (int)strlen((char *)src->multi_src.string);
 
 	    /* Wasteful, throwing away the WC string, but need side effect! */
 	    (void)_XawTextMBToWC(d, (char *)src->multi_src.string, &length);
 	    src->multi_src.length = (XawTextPosition)length;
 	}
 	else {
-	    src->multi_src.length = strlen((char *)src->multi_src.string);
+	    src->multi_src.length = (XawTextPosition)strlen((char *)src->multi_src.string);
 	    /* In case the length resource is incorrectly set */
 	    if (src->multi_src.length > src->multi_src.multi_length)
-		src->multi_src.multi_length = src->multi_src.length;
+		src->multi_src.multi_length = (int)src->multi_src.length;
 
-	    if (src->multi_src.multi_length == MAGIC_VALUE) 
+	    if (src->multi_src.multi_length == MAGIC_VALUE)
 		src->multi_src.piece_size = src->multi_src.length;
 	    else
 		src->multi_src.piece_size = src->multi_src.multi_length + 1;
 	}
-		
+
 	return (NULL);
     }
 
@@ -1223,7 +1221,7 @@ InitStringOrFile(MultiSrcObject src, Bool newString)
 	case XawtextAppend:
 	case XawtextEdit:
 	    if (src->multi_src.string == NULL) {
-		src->multi_src.string = "*multi-src*";
+		src->multi_src.string = (char *)"*multi-src*";
 		src->multi_src.is_tempfile = True;
 	    }
 	    else {
@@ -1245,26 +1243,28 @@ InitStringOrFile(MultiSrcObject src, Bool newString)
     /* If is_tempfile, allocate a private copy of the text
      * Unlikely to be changed, just to set allocated_string */
     if (newString || src->multi_src.is_tempfile) {
-	String temp = XtNewString((char *)src->multi_src.string);
+	char * temp = XtNewString((char *)src->multi_src.string);
 
 	if (src->multi_src.allocated_string)
 	    XtFree((char *)src->multi_src.string);
 	src->multi_src.string = temp;
 	src->multi_src.allocated_string = True;
     }
-    
+
     if (!src->multi_src.is_tempfile) {
-	if ((fd = open((char *)src->multi_src.string, open_mode, 0666)) != -1) {
+	if ((fd = open((char *)src->multi_src.string, (int)open_mode, 0666)) != -1) {
 	    if ((file = fdopen(fd, fdopen_mode)) != NULL) {
 		(void)fseek(file, 0, SEEK_END);
 		src->multi_src.length = (XawTextPosition)ftell(file);
 		return(file);
 	    }
+	    else
+		close(fd);
 	}
 	{
 	    String params[2];
 	    Cardinal num_params = 2;
-	    
+
 	    params[0] = (String)src->multi_src.string;
 	    params[1] = strerror(errno);
 	    XtAppWarningMsg(XtWidgetToApplicationContext((Widget)src),
@@ -1294,52 +1294,52 @@ LoadPieces(MultiSrcObject src, FILE *file, char *string)
     int bytes = sizeof(wchar_t);
     char* temp_mb_holder = NULL;
 
-    /* 
-     * This is tricky - the _XawTextMBtoWC converter uses its 3rd arg 
-     * in as MB length, out as WC length.  We want local_length to be 
-     * WC count. 
+    /*
+     * This is tricky - the _XawTextMBtoWC converter uses its 3rd arg
+     * in as MB length, out as WC length.  We want local_length to be
+     * WC count.
      */
-    int local_length = src->multi_src.length;
+    int local_length = (int)src->multi_src.length;
 
     if (string != NULL) {
-	/* 
-	 * ASSERT: IF our caller passed a non-null string, THEN 
-	 * src->multi_src.length is currently string's * byte count, 
+	/*
+	 * ASSERT: IF our caller passed a non-null string, THEN
+	 * src->multi_src.length is currently string's * byte count,
 	 * AND string is in a MB format
 	*/
 	local_str = _XawTextMBToWC(d, (char *)string, &local_length);
 	src->multi_src.length = (XawTextPosition) local_length;
     }
     else if (src->multi_src.type != XawAsciiFile) {
-	/* 
-	 * here, we are not changing the contents, just reloading, 
+	/*
+	 * here, we are not changing the contents, just reloading,
 	 * so don't change len...
 	 */
-	local_length = src->multi_src.string ?
-	    strlen((char *)src->multi_src.string) : 0;
+	local_length = (int)(src->multi_src.string ?
+	    strlen((char *)src->multi_src.string) : 0);
 	local_str = _XawTextMBToWC(d, (char *)src->multi_src.string,
 				   &local_length);
     }
     else {
 	if (src->multi_src.length != 0) {
-	    temp_mb_holder = 
-		XtMalloc((src->multi_src.length + 1) * sizeof(unsigned char));
-	    fseek(file, 0, 0);
-	    src->multi_src.length = fread(temp_mb_holder,
-					  (Size_t)sizeof(unsigned char), 
-					  (Size_t)src->multi_src.length, file);
-	    if (src->multi_src.length <= 0) 
+	    temp_mb_holder =
+		XtMalloc(((size_t)(src->multi_src.length + 1) * sizeof(unsigned char)));
+	    fseek(file, 0, SEEK_SET);
+	    src->multi_src.length = (XawTextPosition)fread(temp_mb_holder,
+					  sizeof(unsigned char),
+					  (size_t)src->multi_src.length, file);
+	    if (src->multi_src.length <= 0)
 		XtAppErrorMsg(XtWidgetToApplicationContext ((Widget) src),
 			      "readError", "multiSource", "XawError",
 			      "fread returned error.", NULL, NULL);
-	    local_length = src->multi_src.length;
+	    local_length = (int)src->multi_src.length;
 	    local_str = _XawTextMBToWC(d, temp_mb_holder, &local_length);
 	    src->multi_src.length = local_length;
 
 	    if (local_str == 0) {
 		String params[2];
 		Cardinal num_params;
-		static char err_text[] = 
+		static char err_text[] =
 		    "<<< FILE CONTENTS NOT REPRESENTABLE IN THIS LOCALE >>>";
 
 		params[0] = XtName(XtParent((Widget)src));
@@ -1352,8 +1352,8 @@ LoadPieces(MultiSrcObject src, FILE *file, char *string)
 				"not representable in this locale.",
 				params, &num_params);
 		src->multi_src.length = sizeof err_text;
-		local_length = src->multi_src.length;
-        	local_str = _XawTextMBToWC(d, err_text, &local_length);
+		local_length = (int)src->multi_src.length;
+		local_str = _XawTextMBToWC(d, err_text, &local_length);
 		src->multi_src.length = local_length;
 	    }
 	}
@@ -1381,7 +1381,7 @@ LoadPieces(MultiSrcObject src, FILE *file, char *string)
 						    * bytes));
 	piece->used = Min(left, src->multi_src.piece_size);
 	if (piece->used != 0)
-	(void)wcsncpy(piece->text, ptr, piece->used);
+	(void)wcsncpy(piece->text, ptr, (size_t)piece->used);
 
 	left -= piece->used;
 	ptr += piece->used;
@@ -1420,7 +1420,7 @@ AllocNewPiece(MultiSrcObject src, MultiPiece *prev)
 	piece->next = prev->next;
 	prev->next = piece;
     }
-  
+
     piece->prev = prev;
 
     return (piece);
@@ -1436,7 +1436,7 @@ AllocNewPiece(MultiSrcObject src, MultiPiece *prev)
  * Description:
  *	Frees all the pieces
  */
-static void 
+static void
 FreeAllPieces(MultiSrcObject src)
 {
     MultiPiece *next, *first = src->multi_src.first_piece;
@@ -1451,7 +1451,7 @@ FreeAllPieces(MultiSrcObject src)
 	RemovePiece(src, first);
     }
 }
-  
+
 /*
  * Function:
  *	RemovePiece
@@ -1511,7 +1511,7 @@ FindPiece(MultiSrcObject src, XawTextPosition position, XawTextPosition *first)
 
     return (old_piece);	  /* if we run off the end the return the last piece */
 }
-    
+
 /*
  * Function:
  *	BreakPiece
@@ -1528,18 +1528,18 @@ static void
 BreakPiece(MultiSrcObject src, MultiPiece *piece)
 {
     MultiPiece *cnew = AllocNewPiece(src, piece);
-  
+
     cnew->text = (wchar_t *)
-	XtMalloc(src->multi_src.piece_size * sizeof(wchar_t));
+	XtMalloc((Cardinal)((size_t)src->multi_src.piece_size * sizeof(wchar_t)));
     (void)wcsncpy(cnew->text, piece->text + HALF_PIECE,
-		  src->multi_src.piece_size - HALF_PIECE);
+		  (size_t)(src->multi_src.piece_size - HALF_PIECE));
     piece->used = HALF_PIECE;
     cnew->used = src->multi_src.piece_size - HALF_PIECE;
 }
 
 /*ARGSUSED*/
 static void
-CvtStringToMultiType(XrmValuePtr args, Cardinal *num_args,
+CvtStringToMultiType(XrmValuePtr args _X_UNUSED, Cardinal *num_args _X_UNUSED,
 		     XrmValuePtr fromVal, XrmValuePtr toVal)
 {
     static XawAsciiType type = XawAsciiString;
@@ -1565,9 +1565,9 @@ CvtStringToMultiType(XrmValuePtr args, Cardinal *num_args,
 
 /*ARGSUSED*/
 static Boolean
-CvtMultiTypeToString(Display *dpy, XrmValuePtr args, Cardinal *num_args,
+CvtMultiTypeToString(Display *dpy, XrmValuePtr args _X_UNUSED, Cardinal *num_args _X_UNUSED,
 		     XrmValuePtr fromVal, XrmValuePtr toVal,
-		     XtPointer *data)
+		     XtPointer *data _X_UNUSED)
 {
     static String buffer;
     Cardinal size;
@@ -1586,7 +1586,7 @@ CvtMultiTypeToString(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	    return (False);
     }
 
-    size = strlen(buffer) + 1;
+    size = (Cardinal)strlen(buffer) + 1;
     if (toVal->addr != NULL) {
 	if (toVal->size < size) {
 	    toVal->size = size;
@@ -1603,7 +1603,7 @@ CvtMultiTypeToString(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 
 /*ARGSUSED*/
 static void
-GetDefaultPieceSize(Widget w, int offset, XrmValue *value)
+GetDefaultPieceSize(Widget w _X_UNUSED, int offset _X_UNUSED, XrmValue *value)
 {
     static XPointer pagesize;
 
