@@ -30,13 +30,13 @@ in this Software without prior written authorization from The Open Group.
  *
  * FileInsert, Search, and Replace.
  *
- * There is also a section at the end for utility functions 
+ * There is also a section at the end for utility functions
  * used by all more than one of these dialogs.
  *
  * The following functions are the only non-static ones defined
  * in this module.  They are located at the begining of the
  * section that contains this dialog box that uses them.
- * 
+ *
  * void _XawTextInsertFileAction(w, event, params, num_params);
  * void _XawTextDoSearchAction(w, event, params, num_params);
  * void _XawTextDoReplaceAction(w, event, params, num_params);
@@ -50,10 +50,9 @@ in this Software without prior written authorization from The Open Group.
 #include <errno.h>
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
-#include <X11/Shell.h> 
+#include <X11/Shell.h>
 #include <X11/Xos.h>
 #include <X11/Xmu/CharSet.h>
-#include <X11/Xmu/SysUtil.h>
 #include <X11/Xaw/TextP.h>
 #include <X11/Xaw/AsciiText.h>
 #include <X11/Xaw/Cardinals.h>
@@ -62,25 +61,25 @@ in this Software without prior written authorization from The Open Group.
 #include <X11/Xaw/Toggle.h>
 #include "XawI18n.h"
 
-static char* INSERT_FILE = "Enter Filename:";
-static char* SEARCH_LABEL_1 = "Use <Tab> to change fields.";
-static char* SEARCH_LABEL_2 = "Use ^q<Tab> for <Tab>.";
-static char* DISMISS_NAME = "cancel";
+static _Xconst char* INSERT_FILE = "Enter Filename:";
+static _Xconst char* SEARCH_LABEL_1 = "Use <Tab> to change fields.";
+static _Xconst char* SEARCH_LABEL_2 = "Use ^q<Tab> for <Tab>.";
+static _Xconst char* DISMISS_NAME = "cancel";
 #define DISMISS_NAME_LEN 6
-static char* FORM_NAME = "form";
-static char* LABEL_NAME = "label";
-static char* TEXT_NAME = "text";
+static _Xconst char* FORM_NAME = "form";
+static _Xconst char* LABEL_NAME = "label";
+static _Xconst char* TEXT_NAME = "text";
 
 #define R_OFFSET      1
 
-typedef void (*AddFunc)(Widget, char*, Widget);
+typedef void (*AddFunc)(Widget, String, Widget);
 
 /*
  * Prototypes
  */
 static void _SetField(Widget, Widget);
-static void AddSearchChildren(Widget, char*, Widget);
-static void AddInsertFileChildren(Widget, char*, Widget);
+static void AddSearchChildren(Widget, String, Widget);
+static void AddInsertFileChildren(Widget, String, Widget);
 static void CenterWidgetOnPoint(Widget, XEvent*);
 static Widget CreateDialog(Widget, String, String, AddFunc);
 static void DoInsert(Widget, XtPointer, XtPointer);
@@ -89,17 +88,17 @@ static void DoReplaceOne(Widget, XtPointer, XtPointer);
 static Bool DoSearch(struct SearchAndReplace*);
 static Widget GetShell(Widget);
 static String GetString(Widget);
-static String GetStringRaw(Widget);
+static _XtString GetStringRaw(Widget);
 static void InitializeSearchWidget(struct SearchAndReplace*,
 				   XawTextScanDirection, Bool);
 static Bool InParams(String, String*, unsigned int);
-static Bool InsertFileNamed(Widget, char*);
+static Bool InsertFileNamed(Widget, String);
 static void PopdownFileInsert(Widget, XtPointer, XtPointer);
 static void PopdownSearch(Widget, XtPointer, XtPointer);
 static Bool Replace(struct SearchAndReplace*, Bool, Bool);
 static void SearchButton(Widget, XtPointer, XtPointer);
-static void SetResource(Widget, char*, XtArgVal);
-static Bool SetResourceByName(Widget, char*, char*, XtArgVal);
+static void SetResource(Widget, String, XtArgVal);
+static Bool SetResourceByName(Widget, String, String, XtArgVal);
 static void SetSearchLabels(struct SearchAndReplace*, String, String, Bool);
 static void SetWMProtocolTranslations(Widget);
 
@@ -132,7 +131,7 @@ static char radio_trans_string[] =
 "<Btn1Down>,<Btn1Up>:"	"set() notify()\n"
 ;
 
-static char search_text_trans[] = 
+static char search_text_trans[] =
 "~s<Key>Return:"	"DoSearchAction(Popdown)\n"
 "s<Key>Return:"		"DoSearchAction() SetField(Replace)\n"
 "c<Key>c:"		"PopdownSearchAction()\n"
@@ -140,7 +139,7 @@ static char search_text_trans[] =
 "<Key>Tab:"		"DoSearchAction() SetField(Replace)\n"
 ;
 
-static char rep_text_trans[] = 
+static char rep_text_trans[] =
 "~s<Key>Return:"	"DoReplaceAction(Popdown)\n"
 "s<Key>Return:"		"SetField(Search)\n"
 "c<Key>c:"		"PopdownSearchAction()\n"
@@ -152,7 +151,7 @@ static char rep_text_trans[] =
  * Implementation
  */
 /*
- * This section of the file contains all the functions that 
+ * This section of the file contains all the functions that
  * the file insert dialog box uses
  */
 
@@ -165,9 +164,9 @@ static char rep_text_trans[] =
  *	that will insert a file into the main Text Widget.
  */
 /*ARGSUSED*/
-void 
-_XawTextInsertFileAction(Widget w, XEvent *event,
-			 String *params, Cardinal *num_params)
+void
+_XawTextInsertFileAction(Widget w, XEvent *event _X_UNUSED,
+			 String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     DoInsert(w, (XtPointer)XtParent(XtParent(XtParent(w))), NULL);
 }
@@ -193,28 +192,28 @@ _XawTextInsertFileAction(Widget w, XEvent *event,
  *	  This entry is optional and contains the value of the default
  *	file to insert
  */
-void 
+void
 _XawTextInsertFile(Widget w, XEvent *event,
 		   String *params, Cardinal *num_params)
 {
     TextWidget ctx = (TextWidget)w;
-    char *ptr;
+    String ptr;
     XawTextEditType edit_mode;
     Arg args[1];
 
     XtSetArg(args[0], XtNeditType, &edit_mode);
     XtGetValues(ctx->text.source, args, 1);
-  
+
     if (edit_mode != XawtextEdit) {
 	XBell(XtDisplay(w), 0);
 	return;
     }
 
-    if (*num_params == 0) 
+    if (*num_params == 0)
 	ptr = "";
-    else 
+    else
 	ptr = params[0];
-    
+
     if (!ctx->text.file_insert) {
 	ctx->text.file_insert = CreateDialog(w, ptr, "insertFile",
 					     AddInsertFileChildren);
@@ -239,8 +238,8 @@ _XawTextInsertFile(Widget w, XEvent *event,
  *	Pops down the file insert button
  */
 /*ARGSUSED*/
-static void 
-PopdownFileInsert(Widget w, XtPointer closure, XtPointer call_data)
+static void
+PopdownFileInsert(Widget w _X_UNUSED, XtPointer closure, XtPointer call_data _X_UNUSED)
 {
     TextWidget ctx = (TextWidget)closure;
 
@@ -261,14 +260,14 @@ PopdownFileInsert(Widget w, XtPointer closure, XtPointer call_data)
  *	Actually insert the file named in the text widget of the file dialog
  */
 /*ARGSUSED*/
-static void 
+static void
 DoInsert(Widget w, XtPointer closure, XtPointer call_data)
 {
     TextWidget ctx = (TextWidget)closure;
     char buf[BUFSIZ], msg[BUFSIZ];
     Widget temp_widget;
 
-    (void)XmuSnprintf(buf, sizeof(buf), "%s.%s", FORM_NAME, TEXT_NAME);
+    snprintf(buf, sizeof(buf), "%s.%s", FORM_NAME, TEXT_NAME);
     if ((temp_widget = XtNameToWidget(ctx->text.file_insert, buf)) == NULL) {
 	(void)strcpy(msg,
 		     "Error: Could not get text widget from file insert popup");
@@ -278,9 +277,9 @@ DoInsert(Widget w, XtPointer closure, XtPointer call_data)
 	return;
     }
     else
-	(void)XmuSnprintf(msg, sizeof(msg), "Error: %s", strerror(errno));
+	snprintf(msg, sizeof(msg), "Error: %s", strerror(errno));
 
-    (void)SetResourceByName(ctx->text.file_insert, 
+    (void)SetResourceByName(ctx->text.file_insert,
 			    LABEL_NAME, XtNlabel, (XtArgVal)msg);
     XBell(XtDisplay(w), 0);
 }
@@ -300,7 +299,7 @@ DoInsert(Widget w, XtPointer closure, XtPointer call_data)
  *	True if the insert was sucessful, False otherwise.
  */
 static Bool
-InsertFileNamed(Widget tw, char *str)
+InsertFileNamed(Widget tw, String str)
 {
     FILE *file;
     XawTextBlock text;
@@ -311,15 +310,15 @@ InsertFileNamed(Widget tw, char *str)
 
     pos = XawTextGetInsertionPoint(tw);
 
-    fseek(file, 0L, 2);
+    fseek(file, 0L, SEEK_END);
 
     text.firstPos = 0;
-    text.length = ftell(file);
-    text.ptr = XtMalloc(text.length + 1);
+    text.length = (int)ftell(file);
+    text.ptr = XtMalloc((Cardinal)(text.length + 1));
     text.format = XawFmt8Bit;
 
-    fseek(file, 0L, 0);
-    if (fread(text.ptr, 1, text.length, file) != text.length)
+    fseek(file, 0L, SEEK_SET);
+    if (fread(text.ptr, 1, (size_t)text.length, file) != (size_t)text.length)
 	XtErrorMsg("readError", "insertFileNamed", "XawError",
 		   "fread returned error", NULL, NULL);
 
@@ -350,7 +349,7 @@ InsertFileNamed(Widget tw, char *str)
  *	Adds all children to the InsertFile dialog widget.
  */
 static void
-AddInsertFileChildren(Widget form, char *ptr, Widget tw)
+AddInsertFileChildren(Widget form, String ptr, Widget tw)
 {
     Arg args[10];
     Cardinal num_args;
@@ -365,7 +364,7 @@ AddInsertFileChildren(Widget form, char *ptr, Widget tw)
     XtSetArg(args[num_args], XtNborderWidth, 0);	num_args++;
     label = XtCreateManagedWidget(LABEL_NAME, labelWidgetClass, form,
 				  args, num_args);
-  
+
     num_args = 0;
     XtSetArg(args[num_args], XtNfromVert, label);	num_args++;
     XtSetArg(args[num_args], XtNleft, XtChainLeft);	num_args++;
@@ -406,7 +405,7 @@ AddInsertFileChildren(Widget form, char *ptr, Widget tw)
 }
 
 /*
- * This section of the file contains all the functions that 
+ * This section of the file contains all the functions that
  * the search dialog box uses
  */
 /*
@@ -419,12 +418,12 @@ AddInsertFileChildren(Widget form, char *ptr, Widget tw)
  *
  * Note:
  * If the search was sucessful and the argument popdown is passed to
- * this action routine then the widget will automatically popdown the 
+ * this action routine then the widget will automatically popdown the
  *	search widget
  */
 /*ARGSUSED*/
-void 
-_XawTextDoSearchAction(Widget w, XEvent *event,
+void
+_XawTextDoSearchAction(Widget w, XEvent *event _X_UNUSED,
 		       String *params, Cardinal *num_params)
 {
     TextWidget tw = (TextWidget)XtParent(XtParent(XtParent(w)));
@@ -432,7 +431,7 @@ _XawTextDoSearchAction(Widget w, XEvent *event,
 
     if (*num_params == 1 && (params[0][0] == 'p' || params[0][0] == 'P'))
 	popdown = True;
-    
+
     if (DoSearch(tw->text.search) && popdown)
 	PopdownSearch(w, (XtPointer)tw->text.search, NULL);
 }
@@ -446,9 +445,9 @@ _XawTextDoSearchAction(Widget w, XEvent *event,
  *	will popdown the search widget.
  */
 /*ARGSUSED*/
-void 
-_XawTextPopdownSearchAction(Widget w, XEvent *event,
-			    String *params, Cardinal *num_params)
+void
+_XawTextPopdownSearchAction(Widget w, XEvent *event _X_UNUSED,
+			    String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     TextWidget tw = (TextWidget)XtParent(XtParent(XtParent(w)));
 
@@ -468,8 +467,8 @@ _XawTextPopdownSearchAction(Widget w, XEvent *event,
  *	Pops down the search widget and resets it
  */
 /*ARGSUSED*/
-static void 
-PopdownSearch(Widget w, XtPointer closure, XtPointer call_data)
+static void
+PopdownSearch(Widget w _X_UNUSED, XtPointer closure, XtPointer call_data _X_UNUSED)
 {
     struct SearchAndReplace *search = (struct SearchAndReplace *)closure;
 
@@ -490,8 +489,8 @@ PopdownSearch(Widget w, XtPointer closure, XtPointer call_data)
  *	Performs a search when the button is clicked.
  */
 /*ARGSUSED*/
-static void 
-SearchButton(Widget w, XtPointer closure, XtPointer call_data)
+static void
+SearchButton(Widget w _X_UNUSED, XtPointer closure, XtPointer call_data _X_UNUSED)
 {
     (void)DoSearch((struct SearchAndReplace *)closure);
 }
@@ -525,20 +524,21 @@ SearchButton(Widget w, XtPointer closure, XtPointer call_data)
  */
 
 #define SEARCH_HEADER	"Text Widget - Search():"
-void 
+void
 _XawTextSearch(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     TextWidget ctx = (TextWidget)w;
     XawTextScanDirection dir;
-    char *ptr, buf[BUFSIZ];
+    String ptr;
+    char buf[BUFSIZ];
     XawTextEditType edit_mode;
     Arg args[1];
     wchar_t wcs[1];
 
     if (*num_params < 1 || *num_params > 2) {
-	(void)XmuSnprintf(buf, sizeof(buf), "%s %s\n%s", SEARCH_HEADER, 
-			  "This action must have only", 
-			  "one or two parameters");
+	snprintf(buf, sizeof(buf), "%s %s\n%s", SEARCH_HEADER,
+		 "This action must have only",
+		 "one or two parameters");
 	XtAppWarning(XtWidgetToApplicationContext(w), buf);
 	return;
     }
@@ -555,18 +555,18 @@ _XawTextSearch(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	ptr = "";
 
     switch(params[0][0]) {
-	case 'b': 		  /* Left */
+	case 'b':		  /* Left */
 	case 'B':
 	    dir = XawsdLeft;
 	    break;
-	case 'f': 		  /* Right */
+	case 'f':		  /* Right */
 	case 'F':
 	    dir = XawsdRight;
 	    break;
 	default:
-	    (void)XmuSnprintf(buf, sizeof(buf), "%s %s\n%s", SEARCH_HEADER, 
-			      "The first parameter must be",
-			      "Either 'backward' or 'forward'");
+	    snprintf(buf, sizeof(buf), "%s %s\n%s", SEARCH_HEADER,
+		     "The first parameter must be",
+		     "Either 'backward' or 'forward'");
 	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
 	    return;
     }
@@ -620,7 +620,7 @@ InitializeSearchWidget(struct SearchAndReplace *search,
 	    SetResource(search->right_toggle, XtNstate, (XtArgVal)True);
 	    break;
     }
-}  
+}
 
 /*
  * Function:
@@ -635,7 +635,7 @@ InitializeSearchWidget(struct SearchAndReplace *search,
  *	Adds all children to the Search Dialog Widget.
  */
 static void
-AddSearchChildren(Widget form, char *ptr, Widget tw)
+AddSearchChildren(Widget form, String ptr, Widget tw)
 {
     Arg args[10];
     Cardinal num_args;
@@ -659,7 +659,7 @@ AddSearchChildren(Widget form, char *ptr, Widget tw)
     XtSetArg(args[num_args], XtNborderWidth, 0);	   num_args++;
     search->label2 = XtCreateManagedWidget("label2", labelWidgetClass, form,
 					   args, num_args);
-  
+
     /*
      * We need to add R_OFFSET to the radio_data, because the value zero (0)
      * has special meaning
@@ -751,7 +751,7 @@ AddSearchChildren(Widget form, char *ptr, Widget tw)
     r_text = XtCreateManagedWidget("replaceText", asciiTextWidgetClass,
 				   form, args, num_args);
     search->rep_text = r_text;
-  
+
     num_args = 0;
     XtSetArg(args[num_args], XtNlabel, "Search");		num_args++;
     XtSetArg(args[num_args], XtNfromVert, r_text);		num_args++;
@@ -845,10 +845,10 @@ DoSearch(struct SearchAndReplace *search)
 
     text.firstPos = 0;
     text.ptr = GetStringRaw(search->search_text);
-    if ((text.format = _XawTextFormat(ctx)) == XawFmtWide)
-	text.length = wcslen((wchar_t*)text.ptr);
+    if ((text.format = (unsigned long)_XawTextFormat(ctx)) == XawFmtWide)
+	text.length = (int)wcslen((wchar_t*)text.ptr);
     else {
-	text.length = strlen(text.ptr);
+	text.length = (int)strlen(text.ptr);
 
 #ifndef OLDXAW
 	if (search->case_sensitive) {
@@ -864,29 +864,29 @@ DoSearch(struct SearchAndReplace *search)
 	}
 #endif /* OLDXAW */
     }
-  
+
     dir = (XawTextScanDirection)(unsigned long)
       ((XPointer)XawToggleGetCurrent(search->left_toggle) - R_OFFSET);
 
     pos = XawTextSearch(tw, dir, &text);
 
-   /* The Raw string in find.ptr may be WC I can't use here, so I re - call 
+   /* The Raw string in find.ptr may be WC I can't use here, so I re - call
      GetString to get a tame version */
 
     if (pos == XawTextSearchError) {
-	char *ptr;
+	String ptr;
 	int len;
 
 	ptr = GetString(search->search_text);
-	len = strlen(ptr);
-	(void)XmuSnprintf(msg, sizeof(msg), "%s", ptr);
+	len = (int)strlen(ptr);
+	snprintf(msg, sizeof(msg), "%s", ptr);
 
 	ptr = strchr(msg, '\n');
-	if (ptr != NULL || sizeof(msg) - 1 < len) {
+	if (ptr != NULL || sizeof(msg) - 1 < (size_t)len) {
 	    if (ptr != NULL)
-		len = ptr - msg + 4;
+		len = (int)(ptr - msg + 4);
 	    else
-		len = strlen(msg);
+		len = (int)strlen(msg);
 
 	    if (len < 4)
 		strcpy(msg, "...");
@@ -913,7 +913,7 @@ DoSearch(struct SearchAndReplace *search)
 }
 
 /*
- * This section of the file contains all the functions that 
+ * This section of the file contains all the functions that
  * the replace dialog box uses
  */
 /*
@@ -925,8 +925,8 @@ DoSearch(struct SearchAndReplace *search)
  *	Text Widget that will replace a string in the main Text Widget.
  */
 /*ARGSUSED*/
-void 
-_XawTextDoReplaceAction(Widget w, XEvent *event,
+void
+_XawTextDoReplaceAction(Widget w, XEvent *event _X_UNUSED,
 			String *params, Cardinal *num_params)
 {
     TextWidget ctx = (TextWidget)XtParent(XtParent(XtParent(w)));
@@ -954,7 +954,7 @@ _XawTextDoReplaceAction(Widget w, XEvent *event,
  */
 /*ARGSUSED*/
 static void
-DoReplaceOne(Widget w, XtPointer closure, XtPointer call_data)
+DoReplaceOne(Widget w _X_UNUSED, XtPointer closure, XtPointer call_data _X_UNUSED)
 {
     Replace((struct SearchAndReplace *)closure, True, False);
 }
@@ -968,13 +968,13 @@ DoReplaceOne(Widget w, XtPointer closure, XtPointer call_data)
  *	closure	  - pointer to the search structure
  *	call_data - (not used)
  *
- * Description: 
+ * Description:
  *	  Replaces every instance of the string in the search dialog's
  *	text widget with the one in the replace dialog's text widget.
  */
 /*ARGSUSED*/
-static void 
-DoReplaceAll(Widget w, XtPointer closure, XtPointer call_data)
+static void
+DoReplaceAll(Widget w _X_UNUSED, XtPointer closure, XtPointer call_data _X_UNUSED)
 {
     Replace((struct SearchAndReplace *)closure, False, False);
 }
@@ -1007,19 +1007,19 @@ Replace(struct SearchAndReplace *search, Bool once_only, Bool show_current)
     Bool redisplay;
 
     find.ptr = GetStringRaw(search->search_text);
-    if ((find.format = _XawTextFormat(ctx)) == XawFmtWide)
-	find.length = (XawTextPosition)wcslen((wchar_t*)find.ptr);
+    if ((find.format = (unsigned long)_XawTextFormat(ctx)) == XawFmtWide)
+	find.length = (int)(XawTextPosition)wcslen((wchar_t*)find.ptr);
     else
-	find.length = (XawTextPosition)strlen(find.ptr);
+	find.length = (int)(XawTextPosition)strlen(find.ptr);
     find.firstPos = 0;
 
     replace.ptr = GetStringRaw(search->rep_text);
     replace.firstPos = 0;
-    if ((replace.format = _XawTextFormat(ctx)) == XawFmtWide)
-	replace.length = wcslen((wchar_t*)replace.ptr);
+    if ((replace.format = (unsigned long)_XawTextFormat(ctx)) == XawFmtWide)
+	replace.length = (int)wcslen((wchar_t*)replace.ptr);
     else
-	replace.length = strlen(replace.ptr);
-    
+	replace.length = (int)strlen(replace.ptr);
+
     dir = (XawTextScanDirection)(unsigned long)
       ((XPointer)XawToggleGetCurrent(search->left_toggle) - R_OFFSET);
 
@@ -1035,18 +1035,18 @@ Replace(struct SearchAndReplace *search, Bool once_only, Bool show_current)
 	    if (new_pos == XawTextSearchError) {
 		if (count == 0) {
 		    char msg[37];
-		    char *ptr;
+		    String ptr;
 		    int len;
 
 		    ptr = GetString(search->search_text);
-		    len = strlen(ptr);
-		    (void)XmuSnprintf(msg, sizeof(msg), "%s", ptr);
+		    len = (int)strlen(ptr);
+		    snprintf(msg, sizeof(msg), "%s", ptr);
 		    ptr = strchr(msg, '\n');
-		    if (ptr != NULL || sizeof(msg) - 1 < len) {
+		    if (ptr != NULL || sizeof(msg) - 1 < (size_t)len) {
 			if (ptr != NULL)
-			    len = ptr - msg + 4;
+			    len = (int)(ptr - msg + 4);
 			else
-			    len = strlen(msg);
+			    len = (int)strlen(msg);
 
 			if (len < 4)
 			    strcpy(msg, "...");
@@ -1153,7 +1153,7 @@ SetSearchLabels(struct SearchAndReplace *search, String msg1, String msg2,
 {
     (void)SetResource(search->label1, XtNlabel, (XtArgVal)msg1);
     (void)SetResource(search->label2, XtNlabel, (XtArgVal)msg2);
-    if (bell) 
+    if (bell)
 	XBell(XtDisplay(search->search_popup), 0);
 }
 
@@ -1170,8 +1170,8 @@ SetSearchLabels(struct SearchAndReplace *search, String msg1, String msg2,
  *		   Text Widget that will send input to the field specified.
  */
 /*ARGSUSED*/
-void 
-_XawTextSetField(Widget w, XEvent *event, String *params, Cardinal *num_params)
+void
+_XawTextSetField(Widget w, XEvent *event _X_UNUSED, String *params, Cardinal *num_params)
 {
     struct SearchAndReplace *search;
     Widget cnew, old;
@@ -1226,7 +1226,7 @@ _SetField(Widget cnew, Widget old)
     }
 
     XtSetKeyboardFocus(XtParent(cnew), cnew);
-						
+
     XtSetArg(args[0], XtNborderColor, &old_border);
     XtSetArg(args[1], XtNbackground, &old_bg);
     XtGetValues(cnew, args, 2);
@@ -1259,12 +1259,12 @@ _SetField(Widget cnew, Widget old)
  *	True if sucessful
  */
 static Bool
-SetResourceByName(Widget shell, char *name, char *res_name, XtArgVal value)
+SetResourceByName(Widget shell, String name, String res_name, XtArgVal value)
 {
     Widget temp_widget;
     char buf[BUFSIZ];
 
-    (void)XmuSnprintf(buf, sizeof(buf), "%s.%s", FORM_NAME, name);
+    snprintf(buf, sizeof(buf), "%s.%s", FORM_NAME, name);
 
     if ((temp_widget = XtNameToWidget(shell, buf)) != NULL) {
 	SetResource(temp_widget, res_name, value);
@@ -1286,10 +1286,10 @@ SetResourceByName(Widget shell, char *name, char *res_name, XtArgVal value)
  *	Sets a resource in a widget
  */
 static void
-SetResource(Widget w, char *res_name, XtArgVal value)
+SetResource(Widget w, String res_name, XtArgVal value)
 {
     Arg args[1];
-  
+
     XtSetArg(args[0], res_name, value);
     XtSetValues( w, args, 1);
 }
@@ -1300,7 +1300,7 @@ SetResource(Widget w, char *res_name, XtArgVal value)
  *
  * Parameters:
  *	text - text widget whose string we will get
- * 
+ *
  * Description:
  *	Gets the value for the string in the popup.
  *
@@ -1320,7 +1320,7 @@ GetString(Widget text)
     return (string);
 }
 
-static String
+static _XtString
 GetStringRaw(Widget tw)
 {
     TextWidget ctx = (TextWidget)tw;
@@ -1352,18 +1352,18 @@ CenterWidgetOnPoint(Widget w, XEvent *event)
     Cardinal num_args;
     Dimension width, height, b_width;
     Position x, y, max_x, max_y;
-  
+
     if (event != NULL) {
 	switch (event->type) {
 	    case ButtonPress:
 	    case ButtonRelease:
-		x = event->xbutton.x_root;
-		y = event->xbutton.y_root;
+		x = (Position)event->xbutton.x_root;
+		y = (Position)event->xbutton.y_root;
 		break;
 	    case KeyPress:
 	    case KeyRelease:
-		x = event->xkey.x_root;
-		y = event->xkey.y_root;
+		x = (Position)event->xkey.x_root;
+		y = (Position)event->xkey.y_root;
 		break;
 	    default:
 		return;
@@ -1378,21 +1378,21 @@ CenterWidgetOnPoint(Widget w, XEvent *event)
     XtSetArg(args[num_args], XtNborderWidth, &b_width); num_args++;
     XtGetValues(w, args, num_args);
 
-    width += b_width << 1;
-    height += b_width << 1;
+    width = (Dimension)(width + (b_width << 1));
+    height = (Dimension)(height + (b_width << 1));
 
-    x -= (Position)(width >> 1);
+    x = (Position)(x - (width >> 1));
     if (x < 0)
 	x = 0;
     if (x > (max_x = (Position)(XtScreen(w)->width - width)))
 	x = max_x;
 
-    y -= (Position)(height >> 1);
+    y = (Position)(y - (height >> 1));
     if (y < 0)
 	y = 0;
     if (y > (max_y = (Position)(XtScreen(w)->height - height)))
 	y = max_y;
-  
+
     num_args = 0;
     XtSetArg(args[num_args], XtNx, x); num_args++;
     XtSetArg(args[num_args], XtNy, y); num_args++;
@@ -1430,7 +1430,7 @@ CreateDialog(Widget parent, String ptr, String name, AddFunc func)
     XtSetArg(args[num_args], XtNgeometry, NULL);		num_args++;
     XtSetArg(args[num_args], XtNallowShellResize, True);	num_args++;
     XtSetArg(args[num_args], XtNtransientFor, GetShell(parent));num_args++;
-    popup = XtCreatePopupShell(name, transientShellWidgetClass, 
+    popup = XtCreatePopupShell(name, transientShellWidgetClass,
 			       parent, args, num_args);
 
     form = XtCreateManagedWidget(FORM_NAME, formWidgetClass, popup, NULL, 0);
@@ -1451,7 +1451,7 @@ CreateDialog(Widget parent, String ptr, String name, AddFunc func)
  *
  * Returns:
  *	  The shell widget among the ancestors of w that is the
- * 	fewest levels up in the widget hierarchy.
+ *	fewest levels up in the widget hierarchy.
  *
  * Description:
  *	Walks up the widget hierarchy to find the topmost shell widget.
@@ -1461,7 +1461,7 @@ GetShell(Widget w)
 {
     while (w != NULL && !XtIsShell(w))
 	w = XtParent(w);
-    
+
     return (w);
 }
 
@@ -1476,7 +1476,7 @@ InParams(String str, String *p, unsigned int n)
     return (False);
 }
 
-static char *WM_DELETE_WINDOW = "WM_DELETE_WINDOW";
+static const char *WM_DELETE_WINDOW = "WM_DELETE_WINDOW";
 
 static void
 WMProtocols(Widget w, XEvent *event, String *params, Cardinal *num_params)
@@ -1496,14 +1496,14 @@ WMProtocols(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
     if ((event->type == ClientMessage
 	 && event->xclient.message_type == wm_protocols
-	 && event->xclient.data.l[0] == wm_delete_window
+	 && (Atom)event->xclient.data.l[0] == wm_delete_window
 	 && (*num_params == 0 || DO_DELETE_WINDOW))
 	|| (event->type != ClientMessage && DO_DELETE_WINDOW)) {
 #undef DO_DELETE_WINDOW
 	Widget cancel;
 	char descendant[DISMISS_NAME_LEN + 2];
 
-	(void)XmuSnprintf(descendant, sizeof(descendant), "*%s", DISMISS_NAME);
+	snprintf(descendant, sizeof(descendant), "*%s", DISMISS_NAME);
 	cancel = XtNameToWidget(w, descendant);
 	if (cancel)
 	    XtCallCallbacks(cancel, XtNcallback, NULL);
@@ -1538,7 +1538,7 @@ SetWMProtocolTranslations(Widget w)
 	actions[0].proc = WMProtocols;
 	list_size++;
 	app_context_list = (XtAppContext *)XtRealloc
-	    ((char *)app_context_list, list_size * sizeof(XtAppContext));
+	    ((char *)app_context_list, (Cardinal)(list_size * sizeof(XtAppContext)));
 	XtAppAddActions(app_context, actions, 1);
 	app_context_list[i] = app_context;
     }
